[SCM] Samba Shared Repository - branch v3-3-stable updated - release-3-3-0-138-g57930cf

Karolin Seeger kseeger at samba.org
Tue Feb 24 07:58:21 GMT 2009


The branch, v3-3-stable has been updated
       via  57930cf3e4eb79b26cd062b51635d1df2d68a0ed (commit)
       via  f0e36527de04d2796097ebd29fba2a25fc2e1c38 (commit)
       via  733d4b54546d6c7c9350cf522d4980877edac6d4 (commit)
       via  1dd4404782ca2d12b3815e7e0fcb6e6045d690b0 (commit)
       via  18dce7a5cdf01ce4151ce2d0c26d9e1b80b50f72 (commit)
      from  e6f556d3820a828bf4a59aceda0e3546e74ef61f (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-3-stable


- Log -----------------------------------------------------------------
commit 57930cf3e4eb79b26cd062b51635d1df2d68a0ed
Author: Karolin Seeger <kseeger at samba.org>
Date:   Tue Feb 24 08:37:27 2009 +0100

    WHATSNEW: Update changes since 3.3.0.
    
    Karolin
    (cherry picked from commit 4f4a15f4c1f4f2f72f3f651b102938c48ac7ab5b)

commit f0e36527de04d2796097ebd29fba2a25fc2e1c38
Author: Jeremy Allison <jra at samba.org>
Date:   Mon Feb 23 16:23:42 2009 -0800

    More warning fixes for Solaris.
    Jeremy.
    (cherry picked from commit aea38950ff4865f1d791cd19619fadcd59eaf480)

commit 733d4b54546d6c7c9350cf522d4980877edac6d4
Author: Jeremy Allison <jra at samba.org>
Date:   Mon Feb 23 15:42:52 2009 -0800

    More warning fixes for Solaris.
    Jeremy.
    (cherry picked from commit 6306dd0cab617930176fdde91641344ef403429b)

commit 1dd4404782ca2d12b3815e7e0fcb6e6045d690b0
Author: Jeremy Allison <jra at samba.org>
Date:   Mon Feb 23 15:02:52 2009 -0800

    Quieten down a boatload of shadowed variable warnings on Solaris.
    Makes real problems easier to spot.
    Jeremy.
    (cherry picked from commit d32b6d5afd6437544c0fc42681351552d89907dc)

commit 18dce7a5cdf01ce4151ce2d0c26d9e1b80b50f72
Author: Björn Jacke <bj at sernet.de>
Date:   Sun Feb 22 00:43:38 2009 +0100

    all BSDs use this evironment variable
    
    Signed-off-by: Stefan Metzmacher <metze at samba.org>
    (cherry picked from commit cd6ae0de52164dd6f50b3614f2511acb3eb15993)
    (cherry picked from commit 1ad5f50bdab761c7d3894e94f8fe3b171ec1b219)

-----------------------------------------------------------------------

Summary of changes:
 WHATSNEW.txt                        |    2 +
 source/client/client.c              |    6 +-
 source/include/proto.h              |    4 +-
 source/lib/ldap_debug_handler.c     |    4 +-
 source/lib/replace/getifaddrs.c     |    9 ----
 source/lib/replace/libreplace_ld.m4 |    2 +-
 source/lib/smbldap.c                |    2 +
 source/lib/system.c                 |    3 +-
 source/lib/util_file.c              |    4 +-
 source/lib/util_tdb.c               |    6 ++-
 source/libgpo/gpo_reg.c             |    8 ++--
 source/librpc/ndr/ndr_sec_helper.c  |    8 ++--
 source/libsmb/libsmb_dir.c          |    2 +-
 source/modules/nfs4_acls.c          |   84 +++++++++++++++++-----------------
 source/modules/nfs4_acls.h          |   10 ++--
 source/modules/vfs_extd_audit.c     |    8 ++--
 source/modules/vfs_solarisacl.c     |    9 ++--
 source/nmbd/nmbd.c                  |   14 +++---
 source/registry/reg_dispatcher.c    |    8 ++--
 source/rpc_server/srv_svcctl_nt.c   |    6 +-
 source/services/services_db.c       |    6 +-
 source/smbd/connection.c            |    2 +-
 source/smbd/open.c                  |    2 +-
 source/smbd/posix_acls.c            |   52 +++++++++++-----------
 source/smbd/server.c                |    2 +-
 source/smbd/sesssetup.c             |    4 +-
 source/utils/profiles.c             |   30 ++++++------
 source/utils/sharesec.c             |    6 +-
 source/utils/smbget.c               |    6 ++-
 source/winbindd/winbindd.c          |    2 +-
 source/winbindd/winbindd_cache.c    |   18 ++++----
 source/winbindd/winbindd_dual.c     |    2 +-
 32 files changed, 164 insertions(+), 167 deletions(-)


Changeset truncated at 500 lines:

diff --git a/WHATSNEW.txt b/WHATSNEW.txt
index 9377d89..141d76b 100644
--- a/WHATSNEW.txt
+++ b/WHATSNEW.txt
@@ -47,6 +47,7 @@ o   Jeremy Allison <jra at samba.org>
     * Backport the semantics of when to delete alternate data streams on a file
       truncate.
     * Fix printf warnings.
+    * Fix warnings on Solaris.
 
 
 o   Michael Adam <obnox at samba.org>
@@ -78,6 +79,7 @@ o   Bjoern Jacke <bj at sernet.de>
     * Add configure check for Tru64 sub-second timestamp resolution.
     * Add Tru64 sub-second resolution timestamp support.
     * Enable IPv6 support for NetBSD and FreeBSD.
+    * Use correct BSD evironment variable.
 
 
 o   Guenter Kukkukk <linux at kukkukk.com>
diff --git a/source/client/client.c b/source/client/client.c
index df92bae..53bd9e6 100644
--- a/source/client/client.c
+++ b/source/client/client.c
@@ -1785,13 +1785,13 @@ static struct file_list {
  Free a file_list structure.
 ****************************************************************************/
 
-static void free_file_list (struct file_list *list_head)
+static void free_file_list (struct file_list *l_head)
 {
 	struct file_list *list, *next;
 
-	for (list = list_head; list; list = next) {
+	for (list = l_head; list; list = next) {
 		next = list->next;
-		DLIST_REMOVE(list_head, list);
+		DLIST_REMOVE(l_head, list);
 		SAFE_FREE(list->file_path);
 		SAFE_FREE(list);
 	}
diff --git a/source/include/proto.h b/source/include/proto.h
index edb0009..72d3ffe 100644
--- a/source/include/proto.h
+++ b/source/include/proto.h
@@ -1374,7 +1374,7 @@ bool unmap_file(void* start, size_t size);
 void *map_file(char *fname, size_t size);
 char **file_lines_load(const char *fname, int *numlines, size_t maxsize);
 char **fd_lines_load(int fd, int *numlines, size_t maxsize);
-char **file_lines_pload(char *syscmd, int *numlines);
+char **file_lines_pload(const char *syscmd, int *numlines);
 void file_lines_free(char **lines);
 void file_lines_slashcont(char **lines);
 bool file_save(const char *fname, void *packet, size_t length);
@@ -3979,7 +3979,7 @@ size_t ndr_size_dom_sid(const struct dom_sid *sid, int flags);
 size_t ndr_size_dom_sid28(const struct dom_sid *sid, int flags);
 size_t ndr_size_dom_sid0(const struct dom_sid *sid, int flags);
 size_t ndr_size_security_ace(const struct security_ace *ace, int flags);
-size_t ndr_size_security_acl(const struct security_acl *acl, int flags);
+size_t ndr_size_security_acl(const struct security_acl *theacl, int flags);
 size_t ndr_size_security_descriptor(const struct security_descriptor *sd, int flags);
 void ndr_print_dom_sid(struct ndr_print *ndr, const char *name, const struct dom_sid *sid);
 void ndr_print_dom_sid2(struct ndr_print *ndr, const char *name, const struct dom_sid *sid);
diff --git a/source/lib/ldap_debug_handler.c b/source/lib/ldap_debug_handler.c
index 2181ff0..98623d1 100644
--- a/source/lib/ldap_debug_handler.c
+++ b/source/lib/ldap_debug_handler.c
@@ -19,13 +19,11 @@
 
 #include "includes.h"
 
-#if HAVE_LDAP
-
+#if defined(HAVE_LDAP) && defined(HAVE_LBER_LOG_PRINT_FN)
 static void samba_ldap_log_print_fn(LDAP_CONST char *data)
 {
 	DEBUG(lp_ldap_debug_threshold(), ("[LDAP] %s", data));
 }
-
 #endif
 
 void init_ldap_debugging(void)
diff --git a/source/lib/replace/getifaddrs.c b/source/lib/replace/getifaddrs.c
index f6f0ec0..3a91bb4 100644
--- a/source/lib/replace/getifaddrs.c
+++ b/source/lib/replace/getifaddrs.c
@@ -84,9 +84,6 @@ int rep_getifaddrs(struct ifaddrs **ifap)
 	char buff[8192];
 	int fd, i, n;
 	struct ifreq *ifr=NULL;
-	struct in_addr ipaddr;
-	struct in_addr nmask;
-	char *iname;
 	struct ifaddrs *curif;
 	struct ifaddrs *lastif = NULL;
 
@@ -164,9 +161,6 @@ int rep_getifaddrs(struct ifaddrs **ifap)
 	char buff[8192];
 	int fd, i, n;
 	struct ifreq *ifr=NULL;
-	struct in_addr ipaddr;
-	struct in_addr nmask;
-	char *iname;
 	struct ifaddrs *curif;
 	struct ifaddrs *lastif = NULL;
 
@@ -265,9 +259,6 @@ int rep_getifaddrs(struct ifaddrs **ifap)
 	int fd, i;
 	struct ifconf ifc;
 	struct ifreq *ifr=NULL;
-	struct in_addr ipaddr;
-	struct in_addr nmask;
-	char *iname;
 	struct ifaddrs *curif;
 	struct ifaddrs *lastif = NULL;
 
diff --git a/source/lib/replace/libreplace_ld.m4 b/source/lib/replace/libreplace_ld.m4
index 81bde46..9529c5e 100644
--- a/source/lib/replace/libreplace_ld.m4
+++ b/source/lib/replace/libreplace_ld.m4
@@ -292,7 +292,7 @@ AC_DEFUN([AC_LIBREPLACE_RUNTIME_LIB_PATH_VAR],
 		*linux*)
 			LIB_PATH_VAR=LD_LIBRARY_PATH
 		;;
-		*netbsd*)
+		*bsd*)
 			LIB_PATH_VAR=LD_LIBRARY_PATH
 		;;
 		*solaris*)
diff --git a/source/lib/smbldap.c b/source/lib/smbldap.c
index 8e7ecdf..7e9f1ac 100644
--- a/source/lib/smbldap.c
+++ b/source/lib/smbldap.c
@@ -581,7 +581,9 @@ static void smbldap_store_state(LDAP *ld, struct smbldap_state *smbldap_state)
 
 int smb_ldap_start_tls(LDAP *ldap_struct, int version)
 { 
+#ifdef LDAP_OPT_X_TLS
 	int rc;
+#endif
 	
 	if (lp_ldap_ssl() != LDAP_SSL_START_TLS) {
 		return LDAP_SUCCESS;
diff --git a/source/lib/system.c b/source/lib/system.c
index 48ecf90..36745b1 100644
--- a/source/lib/system.c
+++ b/source/lib/system.c
@@ -2171,7 +2171,6 @@ static ssize_t solaris_read_xattr(int attrfd, void *value, size_t size)
 static ssize_t solaris_list_xattr(int attrdirfd, char *list, size_t size)
 {
 	ssize_t len = 0;
-	int stop = 0;
 	DIR *dirp;
 	struct dirent *de;
 	int newfd = dup(attrdirfd);
@@ -2243,7 +2242,7 @@ static int solaris_openat(int fildes, const char *path, int oflag, mode_t mode)
 {
 	int filedes = openat(fildes, path, oflag, mode);
 	if (filedes == -1) {
-		DEBUG(10,("openat FAILED: fd: %s, path: %s, errno: %s\n",filedes,path,strerror(errno)));
+		DEBUG(10,("openat FAILED: fd: %d, path: %s, errno: %s\n",filedes,path,strerror(errno)));
 		if (errno == EINVAL) {
 			errno = ENOTSUP;
 		} else {
diff --git a/source/lib/util_file.c b/source/lib/util_file.c
index b628b06..f9ffa44 100644
--- a/source/lib/util_file.c
+++ b/source/lib/util_file.c
@@ -101,7 +101,7 @@ char *fgets_slash(char *s2,int maxlen,XFILE *f)
  Load from a pipe into memory.
 ****************************************************************************/
 
-static char *file_pload(char *syscmd, size_t *size)
+static char *file_pload(const char *syscmd, size_t *size)
 {
 	int fd, n;
 	char *p;
@@ -351,7 +351,7 @@ char **fd_lines_load(int fd, int *numlines, size_t maxsize)
  must be freed with file_lines_free(). 
 ****************************************************************************/
 
-char **file_lines_pload(char *syscmd, int *numlines)
+char **file_lines_pload(const char *syscmd, int *numlines)
 {
 	char *p;
 	size_t size;
diff --git a/source/lib/util_tdb.c b/source/lib/util_tdb.c
index 6d61fd9..e8f6c67 100644
--- a/source/lib/util_tdb.c
+++ b/source/lib/util_tdb.c
@@ -1097,7 +1097,8 @@ int tdb_validate(struct tdb_context *tdb, tdb_validate_data_func validate_fn)
 
 	/* parent */
 
-	DEBUG(10, ("tdb_validate: fork succeeded, child PID = %d\n",child_pid));
+	DEBUG(10, ("tdb_validate: fork succeeded, child PID = %u\n",
+		(unsigned int)child_pid));
 
 	DEBUG(10, ("tdb_validate: waiting for child to finish...\n"));
 	while  ((wait_pid = sys_waitpid(child_pid, &child_status, 0)) < 0) {
@@ -1113,7 +1114,8 @@ int tdb_validate(struct tdb_context *tdb, tdb_validate_data_func validate_fn)
 	}
 	if (wait_pid != child_pid) {
 		DEBUG(1, ("tdb_validate: waitpid returned pid %d, "
-			  "but %d was expected\n", wait_pid, child_pid));
+			  "but %u was expected\n", wait_pid,
+			(unsigned int)child_pid));
 		goto done;
 	}
 
diff --git a/source/libgpo/gpo_reg.c b/source/libgpo/gpo_reg.c
index d493150..9b694b4 100644
--- a/source/libgpo/gpo_reg.c
+++ b/source/libgpo/gpo_reg.c
@@ -691,7 +691,7 @@ static WERROR gp_reg_generate_sd(TALLOC_CTX *mem_ctx,
 	SEC_ACE ace[6];
 	uint32_t mask;
 
-	SEC_ACL *acl = NULL;
+	SEC_ACL *theacl = NULL;
 
 	uint8_t inherit_flags;
 
@@ -735,15 +735,15 @@ static WERROR gp_reg_generate_sd(TALLOC_CTX *mem_ctx,
 		     SEC_ACE_TYPE_ACCESS_ALLOWED,
 		     mask, inherit_flags);
 
-	acl = make_sec_acl(mem_ctx, NT4_ACL_REVISION, 6, ace);
-	W_ERROR_HAVE_NO_MEMORY(acl);
+	theacl = make_sec_acl(mem_ctx, NT4_ACL_REVISION, 6, ace);
+	W_ERROR_HAVE_NO_MEMORY(theacl);
 
 	*sd = make_sec_desc(mem_ctx, SEC_DESC_REVISION,
 			    SEC_DESC_SELF_RELATIVE |
 			    SEC_DESC_DACL_AUTO_INHERITED | /* really ? */
 			    SEC_DESC_DACL_AUTO_INHERIT_REQ, /* really ? */
 			    NULL, NULL, NULL,
-			    acl, sd_size);
+			    theacl, sd_size);
 	W_ERROR_HAVE_NO_MEMORY(*sd);
 
 	return WERR_OK;
diff --git a/source/librpc/ndr/ndr_sec_helper.c b/source/librpc/ndr/ndr_sec_helper.c
index 90ede5f..72061fa 100644
--- a/source/librpc/ndr/ndr_sec_helper.c
+++ b/source/librpc/ndr/ndr_sec_helper.c
@@ -95,14 +95,14 @@ size_t ndr_size_security_ace(const struct security_ace *ace, int flags)
 /*
   return the wire size of a security_acl
 */
-size_t ndr_size_security_acl(const struct security_acl *acl, int flags)
+size_t ndr_size_security_acl(const struct security_acl *theacl, int flags)
 {
 	size_t ret;
 	int i;
-	if (!acl) return 0;
+	if (!theacl) return 0;
 	ret = 8;
-	for (i=0;i<acl->num_aces;i++) {
-		ret += ndr_size_security_ace(&acl->aces[i], flags);
+	for (i=0;i<theacl->num_aces;i++) {
+		ret += ndr_size_security_ace(&theacl->aces[i], flags);
 	}
 	return ret;
 }
diff --git a/source/libsmb/libsmb_dir.c b/source/libsmb/libsmb_dir.c
index 610cfcd..89782ce 100644
--- a/source/libsmb/libsmb_dir.c
+++ b/source/libsmb/libsmb_dir.c
@@ -1520,7 +1520,7 @@ SMBC_chmod_ctx(SMBCCTX *context,
 		return -1;
 	}
 
-	DEBUG(4, ("smbc_chmod(%s, 0%3o)\n", fname, newmode));
+	DEBUG(4, ("smbc_chmod(%s, 0%3o)\n", fname, (unsigned int)newmode));
 
 	if (SMBC_parse_path(frame,
                             context,
diff --git a/source/modules/nfs4_acls.c b/source/modules/nfs4_acls.c
index ba03847..7756f8f 100644
--- a/source/modules/nfs4_acls.c
+++ b/source/modules/nfs4_acls.c
@@ -44,10 +44,10 @@ typedef struct _SMB_ACL4_INT_T
 	SMB_ACE4_INT_T	*last;
 } SMB_ACL4_INT_T;
 
-static SMB_ACL4_INT_T *get_validated_aclint(SMB4ACL_T *acl)
+static SMB_ACL4_INT_T *get_validated_aclint(SMB4ACL_T *theacl)
 {
-	SMB_ACL4_INT_T *aclint = (SMB_ACL4_INT_T *)acl;
-	if (acl==NULL)
+	SMB_ACL4_INT_T *aclint = (SMB_ACL4_INT_T *)theacl;
+	if (theacl==NULL)
 	{
 		DEBUG(2, ("acl is NULL\n"));
 		errno = EINVAL;
@@ -83,21 +83,21 @@ static SMB_ACE4_INT_T *get_validated_aceint(SMB4ACE_T *ace)
 SMB4ACL_T *smb_create_smb4acl(void)
 {
 	TALLOC_CTX *mem_ctx = talloc_tos();
-	SMB_ACL4_INT_T	*acl = (SMB_ACL4_INT_T *)TALLOC_ZERO_SIZE(mem_ctx, sizeof(SMB_ACL4_INT_T));
-	if (acl==NULL)
+	SMB_ACL4_INT_T	*theacl = (SMB_ACL4_INT_T *)TALLOC_ZERO_SIZE(mem_ctx, sizeof(SMB_ACL4_INT_T));
+	if (theacl==NULL)
 	{
 		DEBUG(0, ("TALLOC_SIZE failed\n"));
 		errno = ENOMEM;
 		return NULL;
 	}
-	acl->magic = SMB_ACL4_INT_MAGIC;
-	/* acl->first, last = NULL not needed */
-	return (SMB4ACL_T *)acl;
+	theacl->magic = SMB_ACL4_INT_MAGIC;
+	/* theacl->first, last = NULL not needed */
+	return (SMB4ACL_T *)theacl;
 }
 
-SMB4ACE_T *smb_add_ace4(SMB4ACL_T *acl, SMB_ACE4PROP_T *prop)
+SMB4ACE_T *smb_add_ace4(SMB4ACL_T *theacl, SMB_ACE4PROP_T *prop)
 {
-	SMB_ACL4_INT_T *aclint = get_validated_aclint(acl);
+	SMB_ACL4_INT_T *aclint = get_validated_aclint(theacl);
 	TALLOC_CTX *mem_ctx = talloc_tos();
 	SMB_ACE4_INT_T *ace;
 
@@ -143,18 +143,18 @@ SMB4ACE_T *smb_next_ace4(SMB4ACE_T *ace)
 	return (SMB4ACE_T *)aceint->next;
 }
 
-SMB4ACE_T *smb_first_ace4(SMB4ACL_T *acl)
+SMB4ACE_T *smb_first_ace4(SMB4ACL_T *theacl)
 {
-	SMB_ACL4_INT_T *aclint = get_validated_aclint(acl);
+	SMB_ACL4_INT_T *aclint = get_validated_aclint(theacl);
 	if (aclint==NULL)
 		return NULL;
 
 	return (SMB4ACE_T *)aclint->first;
 }
 
-uint32 smb_get_naces(SMB4ACL_T *acl)
+uint32 smb_get_naces(SMB4ACL_T *theacl)
 {
-	SMB_ACL4_INT_T *aclint = get_validated_aclint(acl);
+	SMB_ACL4_INT_T *aclint = get_validated_aclint(theacl);
 	if (aclint==NULL)
 		return 0;
 
@@ -195,7 +195,7 @@ static int smbacl4_fGetFileOwner(files_struct *fsp, SMB_STRUCT_STAT *psbuf)
 	return 0;
 }
 
-static bool smbacl4_nfs42win(TALLOC_CTX *mem_ctx, SMB4ACL_T *acl, /* in */
+static bool smbacl4_nfs42win(TALLOC_CTX *mem_ctx, SMB4ACL_T *theacl, /* in */
 	DOM_SID *psid_owner, /* in */
 	DOM_SID *psid_group, /* in */
 	bool is_directory, /* in */
@@ -203,15 +203,15 @@ static bool smbacl4_nfs42win(TALLOC_CTX *mem_ctx, SMB4ACL_T *acl, /* in */
 	int *pgood_aces /* out */
 )
 {
-	SMB_ACL4_INT_T *aclint = (SMB_ACL4_INT_T *)acl;
+	SMB_ACL4_INT_T *aclint = (SMB_ACL4_INT_T *)theacl;
 	SMB_ACE4_INT_T *aceint;
 	SEC_ACE *nt_ace_list = NULL;
 	int good_aces = 0;
 
 	DEBUG(10, ("smbacl_nfs42win entered"));
 
-	aclint = get_validated_aclint(acl);
-	/* We do not check for naces being 0 or acl being NULL here because it is done upstream */
+	aclint = get_validated_aclint(theacl);
+	/* We do not check for naces being 0 or theacl being NULL here because it is done upstream */
 	/* in smb_get_nt_acl_nfs4(). */
 	nt_ace_list = (SEC_ACE *)TALLOC_ZERO_SIZE(mem_ctx, aclint->naces * sizeof(SEC_ACE));
 	if (nt_ace_list==NULL)
@@ -275,7 +275,7 @@ static bool smbacl4_nfs42win(TALLOC_CTX *mem_ctx, SMB4ACL_T *acl, /* in */
 
 static NTSTATUS smb_get_nt_acl_nfs4_common(const SMB_STRUCT_STAT *sbuf,
 	uint32 security_info,
-	SEC_DESC **ppdesc, SMB4ACL_T *acl)
+	SEC_DESC **ppdesc, SMB4ACL_T *theacl)
 {
 	int	good_aces = 0;
 	DOM_SID sid_owner, sid_group;
@@ -284,7 +284,7 @@ static NTSTATUS smb_get_nt_acl_nfs4_common(const SMB_STRUCT_STAT *sbuf,
 	SEC_ACL *psa = NULL;
 	TALLOC_CTX *mem_ctx = talloc_tos();
 
-	if (acl==NULL || smb_get_naces(acl)==0)
+	if (theacl==NULL || smb_get_naces(theacl)==0)
 		return NT_STATUS_ACCESS_DENIED; /* special because we
 						 * shouldn't alloc 0 for
 						 * win */
@@ -292,7 +292,7 @@ static NTSTATUS smb_get_nt_acl_nfs4_common(const SMB_STRUCT_STAT *sbuf,
 	uid_to_sid(&sid_owner, sbuf->st_uid);
 	gid_to_sid(&sid_group, sbuf->st_gid);
 
-	if (smbacl4_nfs42win(mem_ctx, acl, &sid_owner, &sid_group, S_ISDIR(sbuf->st_mode),
+	if (smbacl4_nfs42win(mem_ctx, theacl, &sid_owner, &sid_group, S_ISDIR(sbuf->st_mode),
 				&nt_ace_list, &good_aces)==False) {
 		DEBUG(8,("smbacl4_nfs42win failed\n"));
 		return map_nt_error_from_unix(errno);
@@ -322,7 +322,7 @@ static NTSTATUS smb_get_nt_acl_nfs4_common(const SMB_STRUCT_STAT *sbuf,
 
 NTSTATUS smb_fget_nt_acl_nfs4(files_struct *fsp,
 			       uint32 security_info,
-			       SEC_DESC **ppdesc, SMB4ACL_T *acl)
+			       SEC_DESC **ppdesc, SMB4ACL_T *theacl)
 {
 	SMB_STRUCT_STAT sbuf;
 
@@ -332,13 +332,13 @@ NTSTATUS smb_fget_nt_acl_nfs4(files_struct *fsp,
 		return map_nt_error_from_unix(errno);
 	}
 
-	return smb_get_nt_acl_nfs4_common(&sbuf, security_info, ppdesc, acl);
+	return smb_get_nt_acl_nfs4_common(&sbuf, security_info, ppdesc, theacl);
 }
 
 NTSTATUS smb_get_nt_acl_nfs4(struct connection_struct *conn,
 			      const char *name,
 			      uint32 security_info,
-			      SEC_DESC **ppdesc, SMB4ACL_T *acl)
+			      SEC_DESC **ppdesc, SMB4ACL_T *theacl)
 {
 	SMB_STRUCT_STAT sbuf;
 
@@ -348,7 +348,7 @@ NTSTATUS smb_get_nt_acl_nfs4(struct connection_struct *conn,
 		return map_nt_error_from_unix(errno);
 	}
 
-	return smb_get_nt_acl_nfs4_common(&sbuf, security_info, ppdesc, acl);
+	return smb_get_nt_acl_nfs4_common(&sbuf, security_info, ppdesc, theacl);
 }
 
 enum smbacl4_mode_enum {e_simple=0, e_special=1};
@@ -399,9 +399,9 @@ static int smbacl4_get_vfs_params(
 	return 0;
 }
 
-static void smbacl4_dump_nfs4acl(int level, SMB4ACL_T *acl)
+static void smbacl4_dump_nfs4acl(int level, SMB4ACL_T *theacl)
 {
-	SMB_ACL4_INT_T *aclint = get_validated_aclint(acl);
+	SMB_ACL4_INT_T *aclint = get_validated_aclint(theacl);
 	SMB_ACE4_INT_T *aceint;
 
 	DEBUG(level, ("NFS4ACL: size=%d\n", aclint->naces));
@@ -423,10 +423,10 @@ static void smbacl4_dump_nfs4acl(int level, SMB4ACL_T *acl)
  * return ace if found matching; otherwise NULL
  */
 static SMB_ACE4PROP_T *smbacl4_find_equal_special(
-	SMB4ACL_T *acl,
+	SMB4ACL_T *theacl,
 	SMB_ACE4PROP_T *aceNew)
 {
-	SMB_ACL4_INT_T *aclint = get_validated_aclint(acl);
+	SMB_ACL4_INT_T *aclint = get_validated_aclint(theacl);
 	SMB_ACE4_INT_T *aceint;
 
 	for(aceint = aclint->first; aceint!=NULL; aceint=(SMB_ACE4_INT_T *)aceint->next) {
@@ -618,14 +618,14 @@ static bool smbacl4_fill_ace4(
 
 static int smbacl4_MergeIgnoreReject(
 	enum smbacl4_acedup_enum acedup,
-	SMB4ACL_T *acl, /* may modify it */
+	SMB4ACL_T *theacl, /* may modify it */
 	SMB_ACE4PROP_T *ace, /* the "new" ACE */
 	bool	*paddNewACE,
 	int	i
 )
 {
 	int	result = 0;
-	SMB_ACE4PROP_T *ace4found = smbacl4_find_equal_special(acl, ace);
+	SMB_ACE4PROP_T *ace4found = smbacl4_find_equal_special(theacl, ace);
 	if (ace4found)
 	{
 		switch(acedup)
@@ -658,14 +658,14 @@ static SMB4ACL_T *smbacl4_win2nfs4(
 	gid_t ownerGID
 )
 {
-	SMB4ACL_T *acl;
+	SMB4ACL_T *theacl;
 	uint32	i;
 	TALLOC_CTX *mem_ctx = talloc_tos();
 
 	DEBUG(10, ("smbacl4_win2nfs4 invoked\n"));
 
-	acl = smb_create_smb4acl();
-	if (acl==NULL)
+	theacl = smb_create_smb4acl();
+	if (theacl==NULL)
 		return NULL;
 
 	for(i=0; i<dacl->num_aces; i++) {
@@ -682,16 +682,16 @@ static SMB4ACL_T *smbacl4_win2nfs4(
 		}
 


-- 
Samba Shared Repository


More information about the samba-cvs mailing list